# get persiann
## download
```bash
$ downloadpersiann --help
usage: downloadpersiann [-h] [-o OUTPUT_DIR] timestart timeend

Downloads persiann data

positional arguments:
  timestart             Start datetime (YYYY-MM-DD)
  timeend               End datetime (YYYY-MM-DD)

options:
  -h, --help            show this help message and exit
  -o OUTPUT_DIR, --output-dir OUTPUT_DIR
```
##process
```bash
```
